from maketoken.makeToken import run 

def maketoken():
    print('running')
    run()
    print('done')
